pub enum TextAlignment {
Left,
Right,
Center,
Justify,
}Expand description
Horizontal text alignment within the layout’s line box.
Per CSS Text Module Level 3 text-align.
Variants
Left
Align lines to the start (left edge for LTR, right edge for RTL).
Right
Align lines to the right edge.
Center
Center lines within the available width.
Justify
Stretch lines to fill the available width by expanding inter-word gaps (the last line of a paragraph is not justified).